@@ -73,6 +73,9 @@ OC.L10N.register(
     "{folders} folders and {bookmarks} bookmarks" : "{folders} φάκελοι και {bookmarks} σελιδοδείκτες",
     "_%n bookmark_::_%n bookmarks_" : ["%n σελιδοδείκτης","%n σελιδοδείκτες"],
     "_%n folder_::_%n folders_" : ["%n φάκελος","%n φάκελοι"],
+    "Add a bookmark" : "Προσθήκη σελιδοδείκτη",
+    "Import bookmarks" : "Εισαγωγή σελιδοδεικτών",
+    "Sync with your browser" : "Συγχρονισμός με τον περιηγητή σας",
     "Select folder" : "Επιλογή φακέλου",
     "Enter folder title" : "Τίτλος φακέλου",
     "Shared by {user}" : "Διαμοιράστηκε από {user}",
@@ -100,18 +103,14 @@ OC.L10N.register(
     "{used} bookmarks of {available} available" : "Διαθέσιμοι  {available} σελιδοδείκτες από {used}",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Οι σελιδοδείκτες σε αρχεία όπως φωτογραφίες ή PDF θα αποθηκευτούν αυτόματα στα αρχεία Nextcloud, ώστε να μπορείτε να τα βρείτε ακόμα και όταν ο σύνδεσμος είναι εκτός σύνδεσης.",
     "No bookmarks here" : "Δεν υπάρχουν σελιδοδείκτες εδώ",
-    "Import bookmarks" : "Εισαγωγή σελιδοδεικτών",
-    "Sync with your browser" : "Συγχρονισμός με τον περιηγητή σας",
     "Import" : "Εισαγωγή",
     "Export" : "Εξαγωγή",
     "Archive path" : "Διαδρομή φακέλου αρχειοθέτησης",
-    "Enter the path of a folder where bookmarked files should be stored" : "Προσθέστε την διαδρομή του φακέλου όπου θα αποθηκεύονται τα αρχεία σελιδοδεικτών",
     "Client apps" : "Εφαρμογές πελάτη",
     "Also check out the collection of client apps that integrate with this app: " : "Ελέγξτε επίσης τη συλλογή των εφαρμογών που ενσωματώνονται με αυτήν την εφαρμογή: ",
     "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Μπορείτε να εγκαταστήσετε αυτήν την εφαρμογή στην αρχική οθόνη της συσκευής σας για γρήγορη πρόσβαση στους σελιδοδείκτες σας στο τηλέφωνό σας. Μπορείτε εύκολα να αφαιρέσετε ξανά την εφαρμογή από την αρχική οθόνη, αν δεν σας αρέσει.",
     "Install on home screen" : "Εγκατάσταση στην αρχική οθόνη",
     "Bookmarklet" : "Εφαρμογίδιο Σελιδοδεικτών",
-    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Σύρετε στους σελιδοδείκτες του περιηγητή και κάντε κλικ σε για γρήγορη αποθήκευση σελιδοδείκτη μιας ιστοσελίδας",
     "Add to {instanceName}" : "Προσθήκη στο {instanceName}",
     "Clear data" : "Εκκαθάριση δεδομένων",
     "Permanently remove all bookmarks from your account." : "Οριστική διαγραφή όλων των σελιδοδεικτών από το λογαριασμό σας.",
@@ -160,10 +159,8 @@ OC.L10N.register(
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "ScreenshotMachine API key",
     "Pageres CLI" : "Pageres CLI",
-    "Simply install the pageres cli on your server and bookmarks will find it." : "Απλά εγκαταστήστε το pageres cli στο διακομιστή σας και οι σελιδοδείκτες θα το βρουν.",
-    "Failed to load settings" : "Αποτυχία φόρτωσης ρυθμίσεων",
     "Failed to save settings" : "Αποτυχία αποθήκευσης ρυθμίσεων",
-    "Add a bookmark" : "Προσθήκη σελιδοδείκτη",
+    "Failed to load settings" : "Αποτυχία φόρτωσης ρυθμίσεων",
     "This URL is already bookmarked! Overwrite?" : "Υπάρχει ήδη σελιδοδείκτης με αυτή τη διεύθυνση URL! Αντικατάσταση;",
     "Enter bookmark title" : "Καταχωρίστε έναν τίτλο σελιδοδείκτη",
     "Enter bookmark URL" : "Καταχωρίστε τη διεύθυνση URL σελιδοδείκτη",
