@@ -9,23 +9,16 @@ OC.L10N.register(
     "Rename" : "Rename",
     "Move" : "Move",
     "Delete" : "Delete",
+    "Select all" : "Select all",
     "New" : "New",
     "New folder" : "New folder",
-    "Grid view" : "Grid view",
-    "List view" : "List view",
-    "Select all" : "Select all",
-    "Root folder" : "Root folder",
+    "Add a bookmark" : "Add a bookmark",
     "Submit" : "Submit",
     "Cancel" : "Cancel",
     "All bookmarks" : "All bookmarks",
     "Recent" : "Recent",
-    "Add a bookmark" : "Add a bookmark",
     "Import" : "Import",
     "Export" : "Export",
-    "Recently added" : "Recently added",
-    "Alphabetically" : "Alphabetically",
-    "Most visited" : "Most visited",
-    "Last modified" : "Last modified",
     "Bookmarklet" : "Bookmarklet",
     "Clear data" : "Clear data",
     "Delete all bookmarks" : "Delete all bookmarks",
@@ -33,7 +26,6 @@ OC.L10N.register(
     "Title" : "Title",
     "Link" : "Link",
     "Tags" : "Tags",
-    "Attachments" : "Attachments",
     "Notes" : "Notes",
     "Owner" : "Owner",
     "Sharing" : "Sharing",
@@ -41,11 +33,10 @@ OC.L10N.register(
     "Copy link" : "Copy link",
     "Allow editing" : "Allow editing",
     "Link copied" : "Link copied",
-    "Select" : "Select",
+    "Privacy" : "Privacy",
     "Previews" : "Previews",
     "Screeenly API URL" : "Screeenly API URL",
     "Screeenly API key" : "Screeenly API key",
-    "Privacy" : "Privacy",
     "This URL is already bookmarked! Overwrite?" : "This URL is already bookmarked! Overwrite?",
     "Folder" : "Folder",
     "Save" : "Save",
