@@ -61,6 +61,9 @@ OC.L10N.register(
     "Enter a link" : "Introduza unha ligazón.",
     "Enter a title" : "Introduza o título",
     "No bookmarks found" : "Non se atoparon marcadores",
+    "Add a bookmark" : "Engadir un marcador",
+    "Import bookmarks" : "Importar os marcadores",
+    "Sync with your browser" : "Sincronizar co seu navegador",
     "Select folder" : "Cartafol seleccionado",
     "Enter folder title" : "Introduza o título do cartafol",
     "Shared by {user}" : "Compartido por {user}",
@@ -81,9 +84,6 @@ OC.L10N.register(
     "{used} bookmarks of {available} available" : "{used} marcadores de {available} disponíbel/is",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Os marcadores de ficheiros como as fotos ou os PDF gardaranse automaticamente nos seus ficheiros do Nextcloud, para que poida atopalos incluso cando a ligazón estea fóra de liña.",
     "No bookmarks here" : "Aquí non hai marcadores. ",
-    "Start by importing bookmarks from a file or synchronizing your browser bookmarks with this app" : "Comece importando marcadores dun ficheiro ou sincronizando os marcadores do seu navegador con esta aplicación",
-    "Import bookmarks" : "Importar os marcadores",
-    "Sync with your browser" : "Sincronizar co seu navegador",
     "Import" : "Importar",
     "Export" : "Exportar",
     "Archive path" : "Ruta do arquivo",
@@ -131,10 +131,8 @@ OC.L10N.register(
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "Clave da API do ScreenshotMachine",
     "Pageres CLI" : "Pageres CLI",
-    "Simply install the pageres cli on your server and bookmarks will find it." : "Simplemente instale o «pageres cli» no seu servidor e os marcadores atoparano.",
-    "Failed to load settings" : "Produciuse un fallo ao cargar os axustes",
     "Failed to save settings" : "Produciuse un fallo ao gardar os axustes",
-    "Add a bookmark" : "Engadir un marcador",
+    "Failed to load settings" : "Produciuse un fallo ao cargar os axustes",
     "This URL is already bookmarked! Overwrite?" : "Este URL xa existe como marcador! Sobrescribilo?",
     "Enter bookmark title" : "Introduza o título do marcador",
     "Enter bookmark URL" : "Introduza o URL do marcador",
