@@ -27,13 +27,19 @@ OC.L10N.register(
     "Delete selection" : "Ištrinti žymėjimą",
     "Select all" : "Pažymėti viską",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Pažymėtas %n adresyno įrašas","Pažymėti %n adresyno įrašai","Pažymėta %n adresyno įrašų","Pažymėtas %n adresyno įrašas"],
+    "Go back" : "Grįžti",
+    "Share folder" : "Bendrinti aplanką",
     "Select one or more tags" : "Pasirinkite vieną ar daugiau žymių",
     "New" : "Nauja",
     "New folder" : "Naujas aplankas",
     "RSS feed copied" : "RSS kanalas nukopijuotas",
     "Enter a link" : "Įveskite nuorodą",
+    "Add a bookmark" : "Pridėti adresyno įrašą",
     "Enter folder title" : "Įveskite aplanko pavadinimą",
     "Shared by {user}" : "Bendrina {user}",
+    "Rename folder" : "Pervadinti aplanką",
+    "Move folder" : "Perkelti aplanką",
+    "Delete folder" : "Ištrinti aplanką",
     "Do you really want to delete this folder?" : "Ar tikrai norite ištrinti šį aplanką?",
     "Submit" : "Pateikti",
     "Cancel" : "Atsisakyti",
@@ -41,6 +47,8 @@ OC.L10N.register(
     "_Moving %n folder_::_Moving %n folders_" : ["Perkeliamas %n aplankas","Perkeliami %n aplankai","Perkeliama %n aplankų","Perkeliamas %n aplankas"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Perkeliamas %n adresyno įrašas","Perkeliami %n adresyno įrašai","Perkeliama %n adresyno įrašų","Perkeliamas %n adresyno įrašas"],
     "Recent" : "Paskiausi",
+    "Files" : "Failai",
+    "New tag" : "Nauja žymė",
     "Untagged" : "Be žymių",
     "No bookmarks here" : "Čia adresyno įrašų nėra",
     "Import" : "Importuoti",
@@ -54,6 +62,7 @@ OC.L10N.register(
     "Link" : "Nuoroda",
     "Tags" : "Žymės",
     "Notes" : "Pastabos",
+    "Open file" : "Atverti failą",
     "Owner" : "Savininkas",
     "Sharing" : "Bendrinimas",
     "Select a user or group" : "Pasirinkti naudotoją ar grupę",
@@ -75,9 +84,8 @@ OC.L10N.register(
     "You can either sign up for free at screeenly.com or setup your own server." : "Galite arba nemokamai užsiregistruoti adresu screeenly.com, arba nusistatyti savo asmeninį serverį.",
     "Screeenly API URL" : "Screeenly API URL",
     "Screeenly API key" : "Screeenly API raktas",
-    "Failed to load settings" : "Nepavyko įkelti nustatymų",
     "Failed to save settings" : "Nepavyko įrašyti nustatymų",
-    "Add a bookmark" : "Pridėti adresyno įrašą",
+    "Failed to load settings" : "Nepavyko įkelti nustatymų",
     "This URL is already bookmarked! Overwrite?" : "Šis URL jau įtrauktas į adresyną! Perrašyti?",
     "Enter bookmark title" : "Įveskite adresyno įrašo pavadinimą",
     "Enter bookmark URL" : "Įveskite adresyno įrašo URL",
