@@ -79,6 +79,9 @@ OC.L10N.register(
     "{folders} folders and {bookmarks} bookmarks" : "{folders} cartellas e {bookmarks} signalibros",
     "_%n bookmark_::_%n bookmarks_" : ["%n signalibru","%n signalibros"],
     "_%n folder_::_%n folders_" : ["%n cartella","%n cartellas"],
+    "Add a bookmark" : "Agiunghe unu signalibru",
+    "Import bookmarks" : "Importa signalibros",
+    "Sync with your browser" : "Sincroniza cun su navigadore tuo",
     "Select folder" : "Seletziona cartella",
     "Enter folder title" : "Inserta tìtulu cartella",
     "Shared by {user}" : "Cumpartzidu dae {user}",
@@ -107,9 +110,6 @@ OC.L10N.register(
     "No bookmarked files" : "Perunu archìviu de signalibros",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Is signalibros pro archìvios che a fotos o PDF ant a èssere sarvados in automàticu in is archìvios tuos de Nextcloud, in manera chi tue ddos potzas agatare fintzas cando ses fora de lìnia.",
     "No bookmarks here" : "Perunu signalibru inoghe",
-    "Start by importing bookmarks from a file or synchronizing your browser bookmarks with this app" : "Cumintza importende is signalibros dae un'archìviu o sincronizende cuddos de su navigadore tuo cun custa aplicatzione",
-    "Import bookmarks" : "Importa signalibros",
-    "Sync with your browser" : "Sincroniza cun su navigadore tuo",
     "Import" : "Importa",
     "Export" : "Esporta",
     "Archive path" : "Caminu archìviu",
@@ -168,10 +168,8 @@ OC.L10N.register(
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "Crae ScreenshotMachine API ",
     "Pageres CLI" : "Pageres CLI",
-    "Simply install the pageres cli on your server and bookmarks will find it." : "Installa in manera simpre sa lìnia de cumandu de pageres in su serbidore tuo e is signalibros l'ant a agatare.",
-    "Failed to load settings" : "No at fatuu a carrigare is impostatziones",
     "Failed to save settings" : "No at fatu a sarvare is informatziones",
-    "Add a bookmark" : "Agiunghe unu signalibru",
+    "Failed to load settings" : "No at fatuu a carrigare is impostatziones",
     "This URL is already bookmarked! Overwrite?" : "Custu URL est giai unu signalibru! Ddu cheres subraiscrìere?",
     "Enter bookmark title" : "Inserta tìtulu de su signalibru",
     "Enter bookmark URL" : "Inserta URL de su signalibru",
