@@ -80,6 +80,9 @@ OC.L10N.register(
     "{folders} folders and {bookmarks} bookmarks" : "Izbrane mape {folders} in zaznamki {bookmarks}",
     "_%n bookmark_::_%n bookmarks_" : ["%n zaznamek","%n zaznamka","%n zaznamki","%n zaznamkov"],
     "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n map"],
+    "Add a bookmark" : "Dodaj zaznamek",
+    "Import bookmarks" : "Uvozi zaznamke",
+    "Sync with your browser" : "Uskladi z brskalnikom",
     "Select folder" : "Izbor mape",
     "Enter folder title" : "Vnesite naziv mape",
     "Shared by {user}" : "V skupni rabi z {user}",
@@ -109,9 +112,6 @@ OC.L10N.register(
     "No bookmarked files" : "Ni še dodanih zaznamkov datotek",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Zaznamki do datotek, kot so slike in dokumenti PDF, bodo samodejno shranjeni med datoteke Nextcloud, zato je dostop mogoč tudi pri delu brez povezave.",
     "No bookmarks here" : "Ni še dodanih zaznamkov.",
-    "Start by importing bookmarks from a file or synchronizing your browser bookmarks with this app" : "Začnite z uvažanjem zaznamkov iz datoteke oziroma z usklajevanjem zaznamkov brskalnika s programom.",
-    "Import bookmarks" : "Uvozi zaznamke",
-    "Sync with your browser" : "Uskladi z brskalnikom",
     "Import" : "Uvozi",
     "Export" : "Izvozi",
     "Archive path" : "Arhiviraj pot",
@@ -171,10 +171,8 @@ OC.L10N.register(
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "Ključ vmesnika API ScreenshotMachine",
     "Pageres CLI" : "Pageres CLI",
-    "Simply install the pageres cli on your server and bookmarks will find it." : "Enostavno namestite vmesnik pozivnika cli na strežnik in program bo sam našel povezavo.",
-    "Failed to load settings" : "Nalaganje nastavitev je spodletelo.",
     "Failed to save settings" : "Shranjevanje nastavitev je spodletelo",
-    "Add a bookmark" : "Dodaj zaznamek",
+    "Failed to load settings" : "Nalaganje nastavitev je spodletelo.",
     "This URL is already bookmarked! Overwrite?" : "Ta naslov URL je že dodan med zaznamke. Ali ga želite prepisati?",
     "Enter bookmark title" : "Naslov zaznamka",
     "Enter bookmark URL" : "Naslov URL zaznamka",
