@@ -79,6 +79,9 @@ OC.L10N.register(
     "{folders} folders and {bookmarks} bookmarks" : "{folders} mappar och {bookmarks} bokmärken",
     "_%n bookmark_::_%n bookmarks_" : ["%n bokmärke","%n bokmärken"],
     "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
+    "Add a bookmark" : "Lägg till ett bokmärke",
+    "Import bookmarks" : "Importera bokmärken",
+    "Sync with your browser" : "Synkronisera med din webbläsare",
     "Select folder" : "Välj mapp",
     "Enter folder title" : "Ange titel",
     "Shared by {user}" : "Delad av {user}",
@@ -107,20 +110,15 @@ OC.L10N.register(
     "No bookmarked files" : "Inga bokmärkta filer",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bokmärken till filer som foton eller PDF-filer sparas automatiskt i ditt Nextcloud så att du fortfarande kan hitta dem även när länken går offline.",
     "No bookmarks here" : "Inga bokmärken här",
-    "Start by importing bookmarks from a file or synchronizing your browser bookmarks with this app" : "Börja med att importera bokmärken från en fil eller synkronisera dina webbläsarbokmärken med denna appen",
-    "Import bookmarks" : "Importera bokmärken",
-    "Sync with your browser" : "Synkronisera med din webbläsare",
     "Import" : "Importera",
     "Export" : "Exportera",
     "Archive path" : "Sökväg till arkiv",
-    "Enter the path of a folder where bookmarked files should be stored" : "Ange sökvägen till en mapp där bokmärkta filer ska lagras",
     "Client apps" : "Klientappar",
     "Also check out the collection of client apps that integrate with this app: " : "Kolla också in samlingen av klientappar som integrerar med den här appen: ",
     "Install web app on device" : "Installera webbapp på denna enhet",
     "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Du kan installera denna appen på hemskärmen av din enhet för att snabbt komma åt dina bokmärken från din mobil. Du kan enkelt ta bort appen från hemskärmen igen ifall du inte gillar det.",
     "Install on home screen" : "Installera på hemskärmen",
     "Bookmarklet" : "Bookmarklet",
-    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Dra till webbläsarens bokmärken och klicka på den för att snabbt bokmärka en webbplats",
     "Add to {instanceName}" : "Lägg till {instanceName}",
     "Clear data" : "Rensa data",
     "Permanently remove all bookmarks from your account." : "Ta bort alla bokmärken från ditt konto permanent.",
@@ -170,10 +168,8 @@ OC.L10N.register(
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "ScreenshotMachine API nyckel",
     "Pageres CLI" : "Pageres CLI",
-    "Simply install the pageres cli on your server and bookmarks will find it." : "Installera pageres cli på din server och appen kommer att hitta den.",
-    "Failed to load settings" : "Kunde inte läsa in inställningar",
     "Failed to save settings" : "Kunde inte spara inställningarna",
-    "Add a bookmark" : "Lägg till ett bokmärke",
+    "Failed to load settings" : "Kunde inte läsa in inställningar",
     "This URL is already bookmarked! Overwrite?" : "Den här webbadressen är redan bokmärkt! Skriva över?",
     "Enter bookmark title" : "Ange titel",
     "Enter bookmark URL" : "Ange bokmärkets webbadress",
