@@ -82,6 +82,9 @@ OC.L10N.register(
     "{folders} folders and {bookmarks} bookmarks" : "{folders} 个文件夹和{bookmarks}枚书签",
     "_%n bookmark_::_%n bookmarks_" : ["%n枚书签"],
     "_%n folder_::_%n folders_" : ["%n个文件夹"],
+    "Add a bookmark" : "添加书签",
+    "Import bookmarks" : "导入标签",
+    "Sync with your browser" : "与你的浏览器同步",
     "Select folder" : "选择文件夹",
     "Enter folder title" : "输入文件夹标题",
     "Shared by {user}" : "由 {user} 共享",
@@ -111,9 +114,6 @@ OC.L10N.register(
     "No bookmarked files" : "无已添加书签的文件",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "照片或PDF等文件的书签会被自动保存到你的 Nextcloud 文件中 因此即使链接下线，你仍然可以找到它们。",
     "No bookmarks here" : "无书签",
-    "Start by importing bookmarks from a file or synchronizing your browser bookmarks with this app" : "要开始，请从文件导入书签，或者用这个应用同步浏览器书签",
-    "Import bookmarks" : "导入标签",
-    "Sync with your browser" : "与你的浏览器同步",
     "Import" : "导入",
     "Export" : "导出",
     "Archive path" : "归档路径",
@@ -175,10 +175,8 @@ OC.L10N.register(
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "ScreenshotMachine API key",
     "Pageres CLI" : "Pageres CLI",
-    "Simply install the pageres cli on your server and bookmarks will find it." : "只需在服务器上安装pageres cli，书签就会找到它",
-    "Failed to load settings" : "无法加载设置",
     "Failed to save settings" : "无法保存设置",
-    "Add a bookmark" : "添加书签",
+    "Failed to load settings" : "无法加载设置",
     "This URL is already bookmarked! Overwrite?" : "此链接已加入书签！是否覆盖？",
     "Enter bookmark title" : "输入书签标题",
     "Enter bookmark URL" : "输入书签网址",
