@@ -17,6 +17,7 @@ use OCA\Bookmarks\Db\SharedFolderMapper;
 use OCA\Bookmarks\Db\ShareMapper;
 use OCA\Bookmarks\Db\TreeMapper;
 use OCA\Bookmarks\Exception\ChildrenOrderValidationError;
+use OCA\Bookmarks\Exception\UnauthenticatedError;
 use OCA\Bookmarks\Exception\UnsupportedOperation;
 use OCA\Bookmarks\Exception\UrlParseError;
 use OCA\Bookmarks\Service\Authorizer;
@@ -566,6 +567,48 @@ class FoldersController extends ApiController {
 		return new Http\DataResponse(['status' => 'success', 'item' => $share->toArray()]);
 	}
 
+	/**
+	 * @return Http\DataResponse
+	 * @NoAdminRequired
+	 * @NoCSRFRequired
+	 * @CORS
+	 * @PublicPage
+	 * @throws UnauthenticatedError
+	 */
+	public function findSharedFolders(): DataResponse {
+		$permissions = $this->authorizer->getPermissionsForFolder(-1, $this->request);
+		if (!Authorizer::hasPermission(Authorizer::PERM_READ, $permissions)) {
+			return new Http\DataResponse(['status' => 'error', 'data' => 'Unauthorized'], Http::STATUS_FORBIDDEN);
+		}
+
+		$shares = $this->shareMapper->findByUser($this->authorizer->getUserId());
+		return new Http\DataResponse(['status' => 'success', 'data' => array_map(function (Share $share) {
+			return [
+				'id' => $share->getFolderId(),
+			];
+		}, $shares)]);
+	}
+
+	/**
+	 * @return Http\DataResponse
+	 * @NoAdminRequired
+	 * @NoCSRFRequired
+	 * @CORS
+	 * @PublicPage
+	 * @throws UnauthenticatedError
+	 */
+	public function findShares(): DataResponse {
+		$permissions = $this->authorizer->getPermissionsForFolder(-1, $this->request);
+		if (Authorizer::hasPermission(Authorizer::PERM_READ, $permissions)) {
+			return new Http\DataResponse(['status' => 'error', 'data' => 'Unauthorized'], Http::STATUS_FORBIDDEN);
+		}
+
+		$shares = $this->shareMapper->findByOwner($this->authorizer->getUserId());
+		return new Http\DataResponse(['status' => 'success', 'data' => array_map(function ($share) {
+			return $share->toArray();
+		}, $shares)]);
+	}
+
 	/**
 	 * @param int $folderId
 	 * @return Http\DataResponse
@@ -573,6 +616,7 @@ class FoldersController extends ApiController {
 	 * @NoCSRFRequired
 	 * @CORS
 	 * @PublicPage
+	 * @throws UnauthenticatedError
 	 */
 	public function getShares($folderId): DataResponse {
 		$permissions = $this->authorizer->getPermissionsForFolder($folderId, $this->request);
