@@ -25,6 +25,7 @@ export const privateRoutes = {
 	UNAVAILABLE: 'UNAVAILABLE',
 	ARCHIVED: 'ARCHIVED',
 	BOOKMARKLET: 'bookmarklet',
+	SHARED_FOLDERS: 'SHARED_FOLDERS',
 }
 
 export const publicRoutes = {
@@ -87,6 +88,11 @@ export default new Router({
 			name: privateRoutes.ARCHIVED,
 			component: ViewPrivate,
 		},
+		{
+			path: '/shared',
+			name: privateRoutes.SHARED_FOLDERS,
+			component: ViewPrivate,
+		},
 		{
 			path: '/bookmarklet',
 			name: privateRoutes.BOOKMARKLET,
