@@ -27,6 +27,7 @@ export const actions = {
 	OPEN_BOOKMARK: 'OPEN_BOOKMARK',
 	SAVE_BOOKMARK: 'SAVE_BOOKMARK',
 	MOVE_BOOKMARK: 'MOVE_BOOKMARK',
+	COPY_BOOKMARK: 'COPY_BOOKMARK',
 	CLICK_BOOKMARK: 'CLICK_BOOKMARK',
 	IMPORT_BOOKMARKS: 'IMPORT_BOOKMARKS',
 	DELETE_BOOKMARKS: 'DELETE_BOOKMARKS',
@@ -44,6 +45,7 @@ export const actions = {
 	OPEN_FOLDER_SHARING: 'OPEN_FOLDER_SHARING',
 
 	MOVE_SELECTION: 'MOVE_SELECTION',
+	COPY_SELECTION: 'COPY_SELECTION',
 	DELETE_SELECTION: 'DELETE_SELECTION',
 	TAG_SELECTION: 'TAG_SELECTION',
 
@@ -57,6 +59,7 @@ export const actions = {
 	FILTER_BY_ARCHIVED: 'FILTER_BY_ARCHIVED',
 	FILTER_BY_TAGS: 'FILTER_BY_TAGS',
 	FILTER_BY_FOLDER: 'FILTER_BY_FOLDER',
+	FILTER_BY_SHARED_FOLDERS: 'FILTER_BY_SHARED_FOLDERS',
 	FILTER_BY_SEARCH: 'FILTER_BY_SEARCH',
 	FETCH_PAGE: 'FETCH_PAGE',
 	FETCH_ALL: 'FETCH_ALL',
@@ -65,6 +68,7 @@ export const actions = {
 	LOAD_SETTING: 'LOAD_SETTING',
 	LOAD_SETTINGS: 'SLOAD_SETTINGS',
 
+	LOAD_SHARES: 'LOAD_SHARES',
 	LOAD_SHARES_OF_FOLDER: 'LOAD_SHARES_OF_FOLDER',
 	CREATE_SHARE: 'CREATE_SHARE',
 	EDIT_SHARE: 'EDIT_SHARE',
@@ -73,7 +77,7 @@ export const actions = {
 	LOAD_PUBLIC_LINK: 'LOAD_PUBLIC_LINK',
 	CREATE_PUBLIC_LINK: 'CREATE_PUBLIC_LINK',
 	DELETE_PUBLIC_LINK: 'DELETE_PUBLIC_LINK',
-
+	LOAD_SHARED_FOLDERS: 'LOAD_SHARED_FOLDERS',
 }
 
 export default {
@@ -276,10 +280,6 @@ export default {
 				})
 				dispatch(actions.LOAD_FOLDER_CHILDREN_ORDER, -1)
 			}
-			dispatch(actions.RELOAD_VIEW)
-
-			// open sidebar
-			return dispatch(actions.OPEN_BOOKMARK, bookmark.id)
 		} catch (err) {
 			console.error(err)
 			commit(mutations.FETCH_END, 'createBookmark')
@@ -349,6 +349,33 @@ export default {
 			throw err
 		}
 	},
+	async [actions.COPY_BOOKMARK](
+		{ commit, dispatch, state },
+		{ bookmark, oldFolder, newFolder }
+	) {
+		if (Number(oldFolder) === Number(newFolder)) {
+			return
+		}
+		commit(mutations.FETCH_START, { type: 'copyBookmark' })
+		try {
+			const response = await axios.post(
+				url(state, `/folder/${newFolder}/bookmarks/${bookmark}`)
+			)
+			if (response.data.status !== 'success') {
+				throw new Error(response.data)
+			}
+			commit(mutations.FETCH_END, 'copyBookmark')
+			dispatch(actions.LOAD_FOLDER_CHILDREN_ORDER, newFolder)
+		} catch (err) {
+			console.error(err)
+			commit(mutations.FETCH_END, 'copyBookmark')
+			commit(
+				mutations.SET_ERROR,
+				AppGlobal.methods.t('bookmarks', 'Failed to copy bookmark')
+			)
+			throw err
+		}
+	},
 	async [actions.CLICK_BOOKMARK]({ commit, dispatch, state }, bookmark) {
 		commit(mutations.FETCH_START, { type: 'clickBookmark' })
 		try {
@@ -730,9 +757,61 @@ export default {
 					if (folderId === folder.id) {
 						throw new Error('Cannot move folder into itself')
 					}
+					commit(mutations.MOVE_FOLDER, { folder: folder.id, target: folderId })
 					const oldParent = folder.parent_folder
 					folder.parent_folder = folderId
 					await dispatch(actions.SAVE_FOLDER, folder.id) // reloads children order for new parent
+					dispatch(
+						actions.LOAD_FOLDER_CHILDREN_ORDER,
+						oldParent
+					)
+				},
+				10
+			)
+			await Parallel.each(
+				state.selection.bookmarks,
+				bookmark => {
+					commit(mutations.REMOVE_BOOKMARK, bookmark.id)
+					return dispatch(actions.MOVE_BOOKMARK, {
+						oldFolder:
+						bookmark.folders[bookmark.folders.length - 1], // FIXME This is veeeery ugly and will cause issues. Inevitably.
+						newFolder: folderId,
+						bookmark: bookmark.id,
+					})
+				},
+				10
+			)
+
+			// Because we're possibly moving across share boundaries we need to recount
+			dispatch(actions.COUNT_BOOKMARKS, -1)
+
+			commit(mutations.FETCH_END, 'moveSelection')
+		} catch (err) {
+			console.error(err)
+			console.error(err.list)
+			commit(mutations.FETCH_END, 'moveSelection')
+			commit(
+				mutations.SET_ERROR,
+				AppGlobal.methods.t(
+					'bookmarks',
+					'Failed to move parts of selection'
+				)
+			)
+			throw err
+		}
+	},
+	async [actions.COPY_SELECTION]({ commit, dispatch, state }, folderId) {
+		commit(mutations.FETCH_START, { type: 'copySelection' })
+		try {
+			await Parallel.each(
+				state.selection.folders,
+				async folder => {
+					if (folderId === folder.id) {
+						throw new Error('Cannot copy folder into itself')
+					}
+					const oldParent = folder.parent_folder
+					folder.parent_folder = folderId
+					await dispatch(actions.SAVE_FOLDER, folder.id) // _s children order for new parent
 					await dispatch(
 						actions.LOAD_FOLDER_CHILDREN_ORDER,
 						oldParent
@@ -746,9 +825,7 @@ export default {
 					state.selection.bookmarks,
 					bookmark => {
 						commit(mutations.REMOVE_BOOKMARK, bookmark.id)
-						return dispatch(actions.MOVE_BOOKMARK, {
-							oldFolder:
-							bookmark.folders[bookmark.folders.length - 1], // FIXME This is veeeery ugly and will cause issues. Inevitably.
+						return dispatch(actions.COPY_BOOKMARK, {
 							newFolder: folderId,
 							bookmark: bookmark.id,
 						})
@@ -757,18 +834,15 @@ export default {
 				),
 			])
 
-			// Because we're possibly moving across share boundaries we need to recount
-			await dispatch(actions.COUNT_BOOKMARKS, -1)
-
-			commit(mutations.FETCH_END, 'moveSelection')
+			commit(mutations.FETCH_END, 'copySelection')
 		} catch (err) {
 			console.error(err)
-			commit(mutations.FETCH_END, 'moveSelection')
+			commit(mutations.FETCH_END, 'copySelection')
 			commit(
 				mutations.SET_ERROR,
 				AppGlobal.methods.t(
 					'bookmarks',
-					'Failed to move parts of selection'
+					'Failed to copy parts of selection'
 				)
 			)
 			throw err
@@ -1040,6 +1114,44 @@ export default {
 		)
 	},
 
+	[actions.LOAD_SHARES]({ commit, dispatch, state }) {
+		return axios
+			.get(url(state, '/share'))
+			.then(async response => {
+				const {
+					data: { data, status },
+				} = response
+				if (status !== 'success') throw new Error(data)
+				const shares = data
+				for (const share of shares) {
+					await commit(mutations.ADD_SHARE, share)
+				}
+			})
+			.catch(err => {
+				console.error(err)
+				// Don't set a notification as this is expected to happen for subfolders of shares that we don't have a RESHAR permission for
+				throw err
+			})
+	},
+	[actions.LOAD_SHARED_FOLDERS]({ commit, dispatch, state }) {
+		return axios
+			.get(url(state, '/folder/shared'))
+			.then(async response => {
+				const {
+					data: { data, status },
+				} = response
+				if (status !== 'success') throw new Error(data)
+				const folders = data
+				for (const folder of folders) {
+					await commit(mutations.ADD_SHARED_FOLDER, folder)
+				}
+			})
+			.catch(err => {
+				console.error(err)
+				// Don't set a notification as this is expected to happen for subfolders of shares that we don't have a RESHAR permission for
+				throw err
+			})
+	},
 	[actions.LOAD_SHARES_OF_FOLDER]({ commit, dispatch, state }, folderId) {
 		if (folderId === -1 || folderId === '-1') {
 			return Promise.resolve()
