@@ -11,6 +11,7 @@ import Actions from './actions'
 import { privateRoutes, publicRoutes } from '../router'
 import { generateUrl } from '@nextcloud/router'
 import { getCurrentUser } from '@nextcloud/auth'
+import { findFolder } from './findFolder'
 
 Vue.use(Vuex)
 
@@ -50,9 +51,9 @@ export default {
 		bookmarks: [],
 		bookmarksById: {},
 		sharesById: {},
+		sharedFoldersById: {},
 		tags: [],
 		folders: [],
-		foldersById: {},
 		childrenByFolder: {},
 		tokensByFolder: {},
 		countsByFolder: {},
@@ -135,24 +136,3 @@ export default {
 		},
 	},
 }
-
-/**
- * @param id
- * @param children
- */
-function findFolder(id, children) {
-	if (!children || !children.length) return []
-	const folders = children.filter(folder => Number(folder.id) === Number(id))
-	if (folders.length) {
-		return folders
-	} else {
-		for (const child of children) {
-			const folders = findFolder(id, child.children)
-			if (folders.length) {
-				folders.push(child)
-				return folders
-			}
-		}
-		return []
-	}
-}
