@@ -6,12 +6,14 @@
 
 import Vue from 'vue'
 import axios from '@nextcloud/axios'
+import { findFolder } from './findFolder'
 
 export const mutations = {
 	SET_AUTH_TOKEN: 'SET_AUTH_TOKEN',
 	DISPLAY_NEW_BOOKMARK: 'DISPLAY_NEW_BOOKMARK',
 	DISPLAY_NEW_FOLDER: 'DISPLAY_NEW_FOLDER',
 	DISPLAY_MOVE_DIALOG: 'DISPLAY_MOVE_DIALOG',
+	DISPLAY_COPY_DIALOG: 'DISPLAY_COPY_DIALOG',
 	RESET_SELECTION: 'RESET_SELECTION',
 	REMOVE_SELECTION_BOOKMARK: 'REMOVE_SELECTION_BOOKMARK',
 	ADD_SELECTION_BOOKMARK: 'ADD_SELECTION_BOOKMARK',
@@ -38,10 +40,12 @@ export const mutations = {
 	SET_ERROR: 'SET_ERROR',
 	SET_NOTIFICATION: 'SET_NOTIFICATION',
 	SET_FOLDERS: 'SET_FOLDERS',
+	MOVE_FOLDER: 'MOVE_FOLDER',
 	SET_SIDEBAR: 'SET_SIDEBAR',
 	SET_SETTING: 'SET_SETTING',
 	SET_VIEW_MODE: 'SET_VIEW_MODE',
 	ADD_SHARE: 'ADD_SHARE',
+	ADD_SHARED_FOLDER: 'ADD_SHARED_FOLDER',
 	REMOVE_SHARE: 'REMOVE_SHARE',
 	ADD_PUBLIC_TOKEN: 'ADD_PUBLIC_TOKEN',
 	REMOVE_PUBLIC_TOKEN: 'REMOVE_PUBLIC_TOKEN',
@@ -73,6 +77,22 @@ export default {
 	[mutations.SET_FOLDERS](state, folders) {
 		state.folders = sortFolders(folders)
 	},
+	[mutations.MOVE_FOLDER](state, { folder, target }) {
+		const currentFolder = findFolder(folder, state.folders)[0]
+		const oldParent = findFolder(currentFolder.parent_folder, state.folders)[0]
+		const index = oldParent.children.indexOf(currentFolder)
+		oldParent.children.splice(index, 1)
+		const newParent = findFolder(target, state.folders)[0]
+		newParent.children.push(currentFolder)
+
+		if (state.childrenByFolder[oldParent.id]) {
+			const index = state.childrenByFolder[oldParent.id].findIndex(item => item.id === currentFolder.id)
+			state.childrenByFolder[oldParent.id].splice(index, 1)
+		}
+		if (state.childrenByFolder[newParent.id]) {
+			state.childrenByFolder[newParent.id].push({ type: 'folder', id: currentFolder.id })
+		}
+	},
 	[mutations.ADD_TAG](state, tag) {
 		state.tags.push({ name: tag, count: 0 })
 	},
@@ -110,6 +130,10 @@ export default {
 		state.displayMoveDialog = display
 	},
 
+	[mutations.DISPLAY_COPY_DIALOG](state, display) {
+		state.displayCopyDialog = display
+	},
+
 	[mutations.RESET_SELECTION](state) {
 		state.selection = { folders: [], bookmarks: [] }
 	},
@@ -147,6 +171,17 @@ export default {
 	[mutations.REMOVE_BOOKMARK](state, id) {
 		const index = state.bookmarks.findIndex(bookmark => bookmark.id === id)
 		if (index !== -1) {
+			const bookmark = state.bookmarks[index]
+			bookmark.folders.forEach(folderId => {
+				if (!state.childrenByFolder[folderId]) {
+					return
+				}
+				const index = state.childrenByFolder[folderId].findIndex(bookmark => bookmark.id === id)
+				if (index !== -1) {
+					return
+				}
+				state.childrenByFolder[folderId].splice(index, 1)
+			})
 			state.bookmarks.splice(index, 1)
 			Vue.delete(state.bookmarksById, id)
 		}
@@ -214,6 +249,10 @@ export default {
 		Vue.set(state.fetchState, 'reachedEnd', true)
 	},
 
+	[mutations.ADD_SHARED_FOLDER](state, folder) {
+		Vue.set(state.sharedFoldersById, folder.id, folder)
+	},
+
 	[mutations.ADD_SHARE](state, share) {
 		Vue.set(state.sharesById, share.id, share)
 	},
